@@ -161,7 +161,7 @@ sprout(tree ** ppr, void *p_data, int *pi_balance, BTREE_CMP * pfi_compare, BTRE
 		    t->left = p1->right;
 		    p1->right = t;
 		    t->bal = 0;
-		    t = p1;
+		    *ppr = t = p1;
 		} else {	/* double LR */
 		    p2 = p1->right;
 		    p1->right = p2->left;
@@ -176,7 +176,7 @@ sprout(tree ** ppr, void *p_data, int *pi_balance, BTREE_CMP * pfi_compare, BTRE
 			p1->bal = -1;
 		    else
 			p1->bal = 0;
-		    t = p2;
+		    *ppr = t = p2;
 		}		/*else */
 		t->bal = 0;
 		*pi_balance = FALSE;
@@ -204,7 +204,7 @@ sprout(tree ** ppr, void *p_data, int *pi_balance, BTREE_CMP * pfi_compare, BTRE
 		    t->right = p1->left;
 		    p1->left = t;
 		    t->bal = 0;
-		    t = p1;
+		    *ppr = t = p1;
 		} else {	/* double RL */
 		    p2 = p1->left;
 		    p1->left = p2->right;
@@ -219,7 +219,7 @@ sprout(tree ** ppr, void *p_data, int *pi_balance, BTREE_CMP * pfi_compare, BTRE
 			p1->bal = 1;
 		    else
 			p1->bal = 0;
-		    t = p2;
+		    *ppr = t = p2;
 		}		/*else */
 		t->bal = 0;
 		*pi_balance = FALSE;
