@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.95.2.17 1997/05/31 23:29:23 wessels Exp $
+ * $Id: squid.h,v 1.95.2.20 1998/06/25 17:15:30 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -258,6 +258,10 @@ typedef unsigned long u_num32;
 #define LOCAL_ARRAY(type,name,size) static type name[size]
 #endif
 
+#if defined(_SQUID_NEXT_) && !defined(S_ISDIR)
+#define S_ISDIR(mode) (((mode) & (_S_IFMT)) == (_S_IFDIR))
+#endif
+
 #include "ansiproto.h"
 
 #ifdef USE_GNUREGEX
