@@ -1,6 +1,6 @@
 
 /*
- * $Id: store_clean.c,v 1.22.2.2 1997/06/06 05:46:14 wessels Exp $
+ * $Id: store_clean.c,v 1.22.2.3 1998/01/02 16:09:25 wessels Exp $
  *
  * DEBUG: section 36    Cache Directory Cleanup
  * AUTHOR: Duane Wessels
@@ -115,7 +115,7 @@ storeDirClean(void *unused)
     if (k > 10)
 	k = 10;
     for (n = 0; n < k; n++) {
-	debug(36, 3, "storeDirClean: Cleaning file %d\n", files[n]);
+	debug(36, 3, "storeDirClean: Cleaning file %08X\n", files[n]);
 	sprintf(p2, "%s/%08X", p1, files[n]);
 	safeunlink(p2, 0);
     }
