@@ -1,6 +1,6 @@
 
 /*
- * $Id: url.c,v 1.54.2.9 1997/07/29 16:09:40 wessels Exp $
+ * $Id: url.c,v 1.54.2.12 1998/05/20 20:47:09 wessels Exp $
  *
  * DEBUG: section 23    URL Parsing
  * AUTHOR: Duane Wessels
@@ -235,12 +235,19 @@ urlParse(method_t method, char *url)
     }
     for (t = host; *t; t++)
 	*t = tolower(*t);
+#if ALLOW_HOSTNAME_UNDERSCORES
+    l = strspn(host,
+	"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+	"abcdefghijklmnopqrstuvwxyz"
+	"0123456789-._");
+#else
     l = strspn(host,
 	"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
 	"abcdefghijklmnopqrstuvwxyz"
 	"0123456789-.");
+#endif
     if (l != strlen(host)) {
-	debug(23, 0, "urlParse: Illegal character in hostname '%s'\n", host);
+	debug(23, 1, "urlParse: Illegal character in hostname '%s'\n", host);
 	return NULL;
     }
     /* remove trailing dots from hostnames */
@@ -375,10 +382,10 @@ matchDomainName(const char *domain, const char *host)
 	return 0;		/* no match at all */
     if (*domain == '.')
 	return 1;
-    if (*(host + offset - 1) == '.')
-	return 1;
     if (offset == 0)
 	return 1;
+    if (*(host + offset - 1) == '.')
+	return 1;
     return 0;
 }
 
